@@ -17,9 +17,11 @@
 # along with this program; see the file COPYING.  If not, write to
 # the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
 
+import re
 import time
 import struct
 import socket
+
 from prewikka import view, User, utils
 
     
@@ -340,10 +342,20 @@ class MessageSummary(Table):
     view_permissions = [ User.PERM_IDMEF_VIEW ]
     view_template = "MessageSummary"
 
-    def getUrlLink(self, url):
-        if not url:
+    def getUrlLink(self, name, url=None):
+        if not name:
             return None
-        
+
+        if not url:            
+            if name.find("http://") != -1:
+                url = name
+
+            elif re.compile("\.[^\s]+\.[^\s+]").search(name):
+                url = "http://" + name
+                
+            else:
+                return name
+            
         external_link_new_window = self.env.config.general.getOptionValue("external_link_new_window", "true")
 
         if (not external_link_new_window and self.env.config.general.has_key("external_link_new_window")) or \
@@ -352,7 +364,7 @@ class MessageSummary(Table):
         else:
             target = "_self"
                 
-        return "<a target='%s' href='%s'>%s</a>" % (target, url, url)
+        return "<a target='%s' href='%s'>%s</a>" % (target, url, name)
                 
     def getTime(self, t):
         if not t:
@@ -405,9 +417,12 @@ class MessageSummary(Table):
 
             if len(addr_list) > 0:
                 addr_list += "<br/>"
-                
-            addr_list += address
-                        
+
+            if addr["category"] in ("ipv4-addr", "ipv6-addr", "ipv4-net", "ipv6-net"):
+                addr_list += self.getUrlLink(address, "https://www.prelude-ids.com/host_details.php?host=%s" % address)
+            else:
+                addr_list += address
+            
         self.newTableEntry("Node address", addr_list)
                 
     def buildAnalyzer(self, analyzer):
@@ -782,7 +797,8 @@ class AlertSummary(TcpIpOptions, MessageSummary, view.View):
             return
         
         if service["port"]:
-            self.newTableEntry("Port", str(service["port"]))
+            port = str(service["port"])
+            self.newTableEntry("Port", self.getUrlLink(port, "https://www.prelude-ids.com/port_details.php?port=%s" % port))
 
         ipn = service["iana_protocol_number"]
         if ipn and utils.protocol_number_to_name(ipn) != None:
